@@ -816,6 +816,8 @@ int fio_clients_send_ini(const char *filename)
 	struct flist_head *entry, *tmp;
 
 	flist_for_each_safe(entry, tmp, &client_list) {
+		bool failed = false;
+
 		client = flist_entry(entry, struct fio_client, list);
 
 		if (client->nr_files) {
@@ -827,12 +829,13 @@ int fio_clients_send_ini(const char *filename)
 				cf = &client->files[i];
 
 				if (fio_client_send_cf(client, cf)) {
+					failed = true;
 					remove_client(client);
 					break;
 				}
 			}
 		}
-		if (client->sent_job)
+		if (client->sent_job || failed)
 			continue;
 		if (!filename || fio_client_send_ini(client, filename, 0))
 			remove_client(client);
@@ -1460,7 +1463,6 @@ static struct cmd_iolog_pdu *convert_iolog(struct fio_net_cmd *cmd,
 		return NULL;
 #endif
 		ret = convert_iolog_gz(cmd, pdu);
-		printf("compressed iolog, %p\n", ret);
 		if (!ret) {
 			log_err("fio: failed decompressing log\n");
 			return NULL;
