@@ -695,6 +695,7 @@ void show_disk_util(int terse, struct json_object *parent,
 {
 	struct flist_head *entry;
 	struct disk_util *du;
+	bool do_json;
 
 	if (!disk_util_mutex)
 		return;
@@ -706,15 +707,17 @@ void show_disk_util(int terse, struct json_object *parent,
 		return;
 	}
 
-	if (output_format & FIO_OUTPUT_JSON)
-		assert(parent);
+	if ((output_format & FIO_OUTPUT_JSON) && parent)
+		do_json = true;
+	else
+		do_json = false;
 
-	if (!terse && !(output_format & FIO_OUTPUT_JSON))
+	if (!terse && !do_json)
 		log_buf(out, "\nDisk stats (read/write):\n");
 
-	if (output_format & FIO_OUTPUT_JSON)
+	if (do_json)
 		json_object_add_disk_utils(parent, &disk_list);
-	if (output_format & ~(FIO_OUTPUT_JSON | FIO_OUTPUT_JSON_PLUS)) {
+	else if (output_format & ~(FIO_OUTPUT_JSON | FIO_OUTPUT_JSON_PLUS)) {
 		flist_for_each(entry, &disk_list) {
 			du = flist_entry(entry, struct disk_util, list);
 
